==> apache-camel-2.25.1-src.zip: apache-camel-2.25.1/components/camel-ahc/src/test/java/org/apache/camel/component/ahc/AhcProduceTransferExceptionTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.ahc;

import org.apache.camel.CamelExecutionException;
import org.apache.camel.builder.RouteBuilder;
import org.junit.Test;

public class AhcProduceTransferExceptionTest extends BaseAhcTest {

    @Test
    public void testAhcProduce() throws Exception {
        getMockEndpoint("mock:result").expectedMessageCount(0);

        try {
            template.sendBody("direct:start", null);
            fail("Should have thrown exception");
        } catch (CamelExecutionException e) {
            MyOrderException cause = assertIsInstanceOf(MyOrderException.class, e.getCause());
            assertNotNull(cause);
            assertEquals("123", cause.getOrderId());
        }

        assertMockEndpointsSatisfied();
    }

    @Override
    protected String getTestServerEndpointUri() {
        return super.getTestServerEndpointUri() + "?transferException=true";
    }

    @Override
    protected String getAhcEndpointUri() {
        return super.getAhcEndpointUri()  + "?transferException=true";
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start")
                    .to(getAhcEndpointUri())
                    .to("mock:result");

                from(getTestServerEndpointUri())
                    .throwException(new MyOrderException("123"));
            }
        };
    }
}

==> apache-camel-3.0.0-src.zip: apache-camel-3.0.0/components/camel-ahc/src/test/java/org/apache/camel/component/ahc/AhcProduceTransferExceptionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.ahc;

import org.apache.camel.CamelExecutionException;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

import static org.apache.camel.test.junit5.TestSupport.assertIsInstanceOf;
import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.fail;

public class AhcProduceTransferExceptionTest extends BaseAhcTest {

    @Test
    public void testAhcProduce() throws Exception {
        getMockEndpoint("mock:result").expectedMessageCount(0);

        try {
            template.sendBody("direct:start", null);
            fail("Should have thrown exception");
        } catch (CamelExecutionException e) {
            MyOrderException cause = assertIsInstanceOf(MyOrderException.class, e.getCause());
            assertNotNull(cause);
            assertEquals("123", cause.getOrderId());
        }

        assertMockEndpointsSatisfied();
    }

    @Override
    protected String getTestServerEndpointUri() {
        return super.getTestServerEndpointUri() + "?transferException=true";
    }

    @Override
    protected String getAhcEndpointUri() {
        return super.getAhcEndpointUri()  + "?transferException=true";
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start")
                    .to(getAhcEndpointUri())
                    .to("mock:result");

                from(getTestServerEndpointUri())
                    .throwException(new MyOrderException("123"));
            }
        };
    }
}
